@@ -1,4 +1,4 @@
-//@line 41 "/usr/obj/i386/xulrunner-1.9.0.14/mozilla/toolkit/components/passwordmgr/content/passwordManagerExceptions.js"
+//@line 41 "/usr/obj/i386/xulrunner-1.9.2.8/mozilla-1.9.2/toolkit/components/passwordmgr/content/passwordManagerExceptions.js"
 
 /*** =================== REJECTED SIGNONS CODE =================== ***/
 
@@ -25,7 +25,10 @@ var rejectsTreeView = {
   cycleHeader : function(column) {},
   getRowProperties : function(row,prop){},
   getColumnProperties : function(column,prop){},
-  getCellProperties : function(row,column,prop){}
+  getCellProperties : function(row,column,prop){
+    if (column.element.getAttribute("id") == "rejectCol")
+      prop.AppendElement(kLTRAtom);
+  }
  };
 
 function Reject(number, host) {
@@ -40,7 +43,7 @@ function LoadRejects() {
 
   // sort and display the table
   rejectsTree.treeBoxObject.view = rejectsTreeView;
-  RejectColumnSort('host');
+  RejectColumnSort(lastRejectSortColumn);
 
   var element = document.getElementById("removeAllRejects");
   if (rejects.length == 0) {
@@ -84,7 +87,7 @@ function HandleRejectKeyPress(e) {
   }
 }
 
-var lastRejectSortColumn = "";
+var lastRejectSortColumn = "host";
 var lastRejectSortAscending = false;
 
 function RejectColumnSort(column) {
@@ -92,4 +95,9 @@ function RejectColumnSort(column) {
     SortTree(rejectsTree, rejectsTreeView, rejects,
                  column, lastRejectSortColumn, lastRejectSortAscending);
   lastRejectSortColumn = column;
+
+  // set the sortDirection attribute to get the styling going
+  var sortedCol = document.getElementById("rejectCol");
+  sortedCol.setAttribute("sortDirection", lastRejectSortAscending ?
+                                          "ascending" : "descending");
 }
